#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SHIFT_LEFT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_SHIFT_LEFT_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/shift_left.hpp>

#endif
